<?php
/**
 *  挖掘线索
 * @author  system
 * @version    1.0
 * @date 2018-11-19 08:23:08
 *
 */

namespace App\Http\Controllers\Admin\Company;

use App\Http\Controllers\Admin\Controller;
use App\Models\CompanyInfoModel;
use App\Models\UserCompanyCollectionModel;
use Illuminate\Http\Request;
use App\Repositories\Company\InfoRepository;

class InfoController extends Controller
{
    private $repository;

    public function __construct(InfoRepository $repository)
    {
        if (!$this->repository) $this->repository = $repository;
    }


    /*
     * 搜索页
     * */
    public function search()
    {
        $fields = (new CompanyInfoModel())->filterFields;
        return view('admin.company.info.search', compact('fields'));
    }

    /**
     * 列表页
     */
    function index(Request $request)
    {
        $search = $request->all();

        $order = array();
        if (isset($request['sort_field']) && $request['sort_field'] && isset($request['sort_field_by'])) {
            $order[$request['sort_field']] = $request['sort_field_by'];
        } else {
            $order['id'] = 'DESC';
        }

        $list = $this->repository->searchCompany($search, $order);

        if ($request->ajax()) {
            $view = view('admin.company.info.data', compact('list'))->render();
            return response()->json(['html' => $view]);
        }

        $fields = (new CompanyInfoModel())->filterFields;


        return view('admin.company.info.index', compact('list', 'fields'));
    }

    /***
     * 创建公海
     * @param Request $request
     * @return int
     */
    public function add_collection(Request $request)
    {
        $filter_fields = $request->except('_token');

        $data['user_id'] = \Auth::guard('admin')->user()->id;
        $data['filter_fields'] = json_encode($filter_fields);
        $data['name'] = '我的公海';

        UserCompanyCollectionModel::create($data);

        return 200;
    }


    public function collection(Request $request)
    {
        if ($request->ajax()) {
            $search = $request->all();

            $order = array();
            if (isset($request['sort_field']) && $request['sort_field'] && isset($request['sort_field_by'])) {
                $order[$request['sort_field']] = $request['sort_field_by'];
            } else {
                $order['id'] = 'DESC';
            }

            $list = $this->repository->searchCompany($search, $order);

            $view = view('admin.company.collection.data', compact('list'))->render();
            return response()->json(['html' => $view]);
        }

        $user_id = \Auth::guard('admin')->user()->id;
        $collection = UserCompanyCollectionModel::where('user_id', $user_id)->first();

        if (count($collection)) {
            $search = (array)json_decode($collection->filter_fields);
            $order = array();
            if (isset($request['sort_field']) && $request['sort_field'] && isset($request['sort_field_by'])) {
                $order[$request['sort_field']] = $request['sort_field_by'];
            } else {
                $order['id'] = 'DESC';
            }

            $list = $this->repository->searchCompany($search, $order);

            $fields = (new CompanyInfoModel())->filterFields;

            return view('admin.company.collection.index', compact('list', 'fields'));
        }

    }


    /**
     * 添加
     */
    public function create(Request $request)
    {
        if ($request->method() == 'POST') {
            return $this->_createSave();
        }
        return view('admin.company.info.edit');
    }

    /**
     * 保存修改
     */
    private function _createSave()
    {
        $data = (array)request('data');
        $id = $this->repository->create($data);
        if ($id) {
            $url[] = array('url' => U('Company/Info/index'), 'title' => '返回列表');
            $url[] = array('url' => U('Company/Info/create'), 'title' => '继续添加');
            $this->showMessage('添加成功', $url);
        } else {
            $url[] = array('url' => U('Company/Info/index'), 'title' => '返回列表');
            return $this->showWarning('添加失败', $url);
        }
    }

    /**
     * 修改
     */
    public function update(Request $request)
    {
        if ($request->method() == 'POST') {
            return $this->_updateSave();
        }
        $data = $this->repository->find($request->get('id'));
        return view('admin.company.info.edit', compact('data'));
    }

    /**
     * 保存修改
     */
    private function _updateSave()
    {
        $data = (array)request('data');
        $ok = $this->repository->update(request('id'), $data);
        if ($ok) {
            $url[] = array('url' => U('Company/Info/index'), 'title' => '返回列表');
            return $this->showMessage('操作成功', urldecode(request('_referer')));
        } else {
            $url[] = array('url' => U('Company/Info/index'), 'title' => '返回列表');
            return $this->showWarning('操作失败', $url);

        }
    }

    public function view(Request $request)
    {
        $data = $this->repository->find(request('id'));
        $contacts = $data->contacts()->orderBy('sort', 'desc')->get();
        return view('admin.company.info.view', compact('data', 'contacts'));
    }


    /**
     * 删除
     */
    public function destroy(Request $request)
    {
        $bool = $this->repository->destroy($request->get('id'));
        if ($bool) {
            return $this->showMessage('操作成功');
        } else {
            return $this->showWarning("操作失败");
        }
    }
}